@@ -40,11 +40,11 @@ def download_from_url(url, dst):
         return file_size
 
     print('Downloading the required environment, Please wait.')
-    #删除不完整的文件
-    try:
-        os.remove(dst)
-    except:
-        pass
+    # #删除不完整的文件
+    # try:
+    #     os.remove(dst)
+    # except:
+    #     pass
     
     header = {"Range": "bytes=%s-%s" % (first_byte, file_size)}
     pbar = tqdm(
